@@ -2,12 +2,13 @@ from __future__ import annotations
 
 import sys
 from collections.abc import Mapping
-from dataclasses import InitVar, dataclass
+from dataclasses import dataclass
 from typing import Dict, List, Optional, Tuple, Type, Union
 
 import xmltodict
 
 from local_tuya.domoticz.units import UnitId
+from local_tuya.protocol import Version
 
 if sys.version_info < (3, 8):
     from importlib_metadata import metadata as pkg_metadata
@@ -34,6 +35,7 @@ class Option:
     def to_xml_dict(self) -> XML:
         return _filter_xml_dict(
             {
+                "@label": self.label,
                 "@value": self.value,
                 "@default": _xml_bool(self.default),
             }
@@ -83,38 +85,8 @@ class PluginMetadata:
     wiki_link: str = ""
     external_link: str = ""
     parameters: Tuple[Parameter, ...] = ()
-    # Add unit ids enum to enable unit selection through plugin params.
-    unit_ids: InitVar[Optional[Type[UnitId]]] = None
 
-    def __post_init__(self, unit_ids: Optional[Type[UnitId]]):
-        self.parameters = (
-            Parameter(field="Username", label="Device ID", required=True),
-            Parameter(field="Address", label="Device IP address", required=True),
-            Parameter(field="Port", label="Device port", default="6668"),
-            Parameter(
-                field="Password", label="Device local key", required=True, password=True
-            ),
-            *self.parameters,
-            *(
-                (
-                    Parameter(
-                        field="Mode5", label="Included units", default=unit_ids.names()
-                    ),
-                )
-                if unit_ids
-                else ()
-            ),
-            Parameter(
-                field="Mode6",
-                label="Debug",
-                options=(
-                    Option(label="No", value="0", default=True),
-                    Option(label="Yes", value="1"),
-                ),
-            ),
-        )
-
-    def definition(self) -> str:
+    def definition(self, unit_ids: Optional[Type[UnitId]]) -> str:
         package_metadata = get_package_metadata(self.package)
         xml = {
             "plugin": _filter_xml_dict(
@@ -128,7 +100,60 @@ class PluginMetadata:
                     or package_metadata.get("Home-page", ""),
                     "description": self.description,
                     "params": {
-                        "param": [p.to_xml_dict() for p in self.parameters],
+                        "param": [
+                            p.to_xml_dict()
+                            for p in (
+                                Parameter(
+                                    field="Username", label="Device ID", required=True
+                                ),
+                                Parameter(
+                                    field="Address",
+                                    label="Device IP address",
+                                    required=True,
+                                ),
+                                Parameter(
+                                    field="Port", label="Device port", default="6668"
+                                ),
+                                Parameter(
+                                    field="Password",
+                                    label="Device local key",
+                                    required=True,
+                                    password=True,
+                                ),
+                                *self.parameters,
+                                Parameter(
+                                    field="Mode4",
+                                    label="Tuya version",
+                                    options=tuple(
+                                        Option(
+                                            label=v.decode(),
+                                            value=v.decode(),
+                                            default=v == Version.v33,
+                                        )
+                                        for v in Version
+                                    ),
+                                ),
+                                *(
+                                    (
+                                        Parameter(
+                                            field="Mode5",
+                                            label="Included units",
+                                            default=unit_ids.names(),
+                                        ),
+                                    )
+                                    if unit_ids
+                                    else ()
+                                ),
+                                Parameter(
+                                    field="Mode6",
+                                    label="Debug",
+                                    options=(
+                                        Option(label="No", value="0", default=True),
+                                        Option(label="Yes", value="1"),
+                                    ),
+                                ),
+                            )
+                        ],
                     },
                 }
             ),
